summaryrefslogtreecommitdiffstats
path: root/chalk/core/kis_group_layer.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/core/kis_group_layer.cc')
-rw-r--r--chalk/core/kis_group_layer.cc20
1 files changed, 10 insertions, 10 deletions
diff --git a/chalk/core/kis_group_layer.cc b/chalk/core/kis_group_layer.cc
index ea8d0213..1f08dbdd 100644
--- a/chalk/core/kis_group_layer.cc
+++ b/chalk/core/kis_group_layer.cc
@@ -90,9 +90,9 @@ bool KisGroupLayer::paintLayerInducesProjectionOptimization(KisPaintLayer* l) {
KisPaintDeviceSP KisGroupLayer::projection(const TQRect & rect)
{
// We don't have a tqparent, and we've got only one child: abuse the child's
// paint device as the projection if the child is visible and 100% opaque
- if (tqparent() == 0 && childCount() == 1) {
+ if (parent() == 0 && childCount() == 1) {
KisPaintLayerSP l = dynamic_cast<KisPaintLayer*>(firstChild().data());
if (paintLayerInducesProjectionOptimization(l)) {
l->setClean(rect);
@@ -146,14 +146,14 @@ KisLayerSP KisGroupLayer::at(int index) const
int KisGroupLayer::index(KisLayerSP layer) const
{
- if (layer->tqparent().data() == this)
+ if (layer->parent().data() == this)
return layer->index();
return -1;
}
void KisGroupLayer::setIndex(KisLayerSP layer, int index)
{
- if (layer->tqparent().data() != this)
+ if (layer->parent().data() != this)
return;
//TODO optimize
removeLayer(layer);
@@ -163,7 +163,7 @@ void KisGroupLayer::setIndex(KisLayerSP layer, int index)
bool KisGroupLayer::addLayer(KisLayerSP newLayer, int x)
{
if (x < 0 || kClamp(uint(x), uint(0), childCount()) != uint(x) ||
- newLayer->tqparent() || m_layers.contains(newLayer))
+ newLayer->parent() || m_layers.contains(newLayer))
{
kdWarning() << "invalid input to KisGroupLayer::addLayer(KisLayerSP newLayer, int x)!" << endl;
return false;
@@ -185,7 +185,7 @@ bool KisGroupLayer::addLayer(KisLayerSP newLayer, int x)
bool KisGroupLayer::addLayer(KisLayerSP newLayer, KisLayerSP aboveThis)
{
- if (aboveThis && aboveThis->tqparent().data() != this)
+ if (aboveThis && aboveThis->parent().data() != this)
{
kdWarning() << "invalid input to KisGroupLayer::addLayer(KisLayerSP newLayer, KisLayerSP aboveThis)!" << endl;
return false;
@@ -219,7 +219,7 @@ bool KisGroupLayer::removeLayer(int x)
bool KisGroupLayer::removeLayer(KisLayerSP layer)
{
- if (layer->tqparent().data() != this)
+ if (layer->parent().data() != this)
{
kdWarning() << "invalid input to KisGroupLayer::removeLayer()!" << endl;
return false;
@@ -317,7 +317,7 @@ void KisGroupLayer::updateProjection(const TQRect & rc)
// If this is the rootlayer, don't do anything with adj. layers that are below the
// first paintlayer
- bool gotPaintLayer = (tqparent() != 0);
+ bool gotPaintLayer = (parent() != 0);
// Look through all the child layers, searching for the first dirty layer
// if it's found, and if we have found an adj. layer before the the dirty layer,
@@ -404,8 +404,8 @@ void KisGroupLayer::updateProjection(const TQRect & rc)
const KisCompositeOp cop = child->compositeOp();
const bool block = child->signalsBlocked();
child->blockSignals(true);
- // Composite op copy doesn't take a tqmask/selection into account, so we need
- // to make a difference between a paintlayer with a tqmask, and one without
+ // Composite op copy doesn't take a mask/selection into account, so we need
+ // to make a difference between a paintlayer with a mask, and one without
KisPaintLayer* l = dynamic_cast<KisPaintLayer*>(child.data());
if (l && l->hasMask())
child->m_compositeOp = COMPOSITE_OVER;
@@ -90,9 +90,9 @@ bool KisGroupLayer::paintLayerInducesProjectionOptimization(KisPaintLayer* l) {
KisPaintDeviceSP KisGroupLayer::projection(const TQRect & rect)
{
- // We don't have a tqparent, and we've got only one child: abuse the child's
+ // We don't have a parent, and we've got only one child: abuse the child's
// paint device as the projection if the child is visible and 100% opaque